src/eric7/Preferences/__init__.py

branch
eric7
changeset 11217
856628e8a303
parent 11216
a1471981ef18
child 11227
023943c77c42
--- a/src/eric7/Preferences/__init__.py	Sun Apr 13 14:46:18 2025 +0200
+++ b/src/eric7/Preferences/__init__.py	Sun Apr 13 15:53:14 2025 +0200
@@ -929,23 +929,6 @@
             ##"interfaces",
             ##"protocols",
         ),
-        "PyQt5": (
-            "sources",
-            "forms",
-            "resources",
-            "translations",
-            "others",
-            ##"interfaces",
-            ##"protocols",
-        ),
-        "PyQt5C": (
-            "sources",
-            "resources",
-            "translations",
-            "others",
-            ##"interfaces",
-            ##"protocols",
-        ),
         "PyQt6": (
             "sources",
             "forms",
@@ -1015,9 +998,7 @@
     helpDefaults = {
         "CustomViewer": "",
         "PythonDocDir": "",
-        "Qt5DocDir": "",
         "Qt6DocDir": "",
-        "PyQt5DocDir": "https://www.riverbankcomputing.com/static/Docs/PyQt5/",
         "PyQt6DocDir": "https://www.riverbankcomputing.com/static/Docs/PyQt6/",
         "PySide6DocDir": "",
         "EricDocDir": "",
@@ -1367,12 +1348,6 @@
         "QtToolsPostfix": "",
         "Lrelease": "",
         "QHelpGenerator": "",
-        # TODO: remove these
-        "PyuicIndent": 4,
-        "PyuicFromImports": False,
-        "PyuicExecute": True,
-        "PyQtVenvName": "",
-        "PyQtToolsDir": "",
         "Pyuic6Indent": 4,
         "Pyuic6Execute": True,
         "PyQt6VenvName": "",
@@ -3066,11 +3041,11 @@
 
 def getQtDocDir(version):
     """
     Module function to retrieve the Qt5DocDir/Qt6DocDir setting.
 
     @param version Qt version to get documentation directory for
     @type int
-    @return the requested Qt5DocDir/Qt6DocDir setting
+    @return the requested QtDocDir setting
     @rtype str
     """
     key = "Qt{0}DocDir".format(version)
@@ -3452,13 +3427,10 @@
     """
     if key in ["Qt6TranslationsDir"]:
         return getQtTranslationsDir()
-    elif key in ["PyuicIndent", "Pyuic6Indent"]:
+    elif key in ["Pyuic6Indent"]:
         return int(Prefs.settings.value("Qt/" + key, Prefs.qtDefaults[key]))
     elif key in [
-        "PyuicFromImports",
-        "PyuicExecute",
         "Pyuic6Execute",
-        "PySide2FromImports",
         "PySide6FromImports",
     ]:
         return EricUtilities.toBool(
@@ -3066,11 +3041,11 @@
 def getQtDocDir(version):
     """
-    Module function to retrieve the Qt5DocDir/Qt6DocDir setting.
+    Module function to retrieve the QtDocDir setting.
 
     @param version Qt version to get documentation directory for

eric ide

mercurial